﻿/*
    『概要』
    EKLを利用して、カメラ画像を表示する最小限のサンプルです。

    EKLの内、主に次の機能が利用されています。
        - FrameExtensions
        - KinectSensorExtensions
*/
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

//追加
using Microsoft.Kinect;
using ExtendKinectLibrary;

namespace SimpleCameraWindowsForms
{
    public partial class Form1 : Form
    {

        KinectSensor kinect;

        public Form1()
        {
            InitializeComponent();

            //Kinectが一台も繋がっていなかったら終了する。
            if (KinectSensor.KinectSensors.Count == 0)
            {
                MessageBox.Show("Failed to find some Kinect sensor.");
                Environment.Exit(0);
            }
            else
            {
                //Kinectの初期化と設定
                kinect = KinectSensor.KinectSensors[0];
                kinect.ColorFrameReady += new EventHandler<ColorImageFrameReadyEventArgs>(kinect_ColorFrameReady);
                kinect.ColorStream.Enable(ColorImageFormat.RgbResolution640x480Fps30);
                kinect.Start();

                //Windowの設定
                this.Closed += new EventHandler(Form1_Closed);
            }
        }

        /// <summary>
        /// Windowが閉じられるときの処理。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void Form1_Closed(object sender, EventArgs e)
        {
            //Kinectを停止してインスタンスを破棄する。
            if(kinect != null)
                kinect.Close();
        }

        /// <summary>
        /// カメラのデータがKinectから流れて来た時の処理。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void kinect_ColorFrameReady(object sender, ColorImageFrameReadyEventArgs e)
        {
            ColorImageFrame temp = e.OpenColorImageFrame();

            if (temp != null)
            {
                //カメラ画像を表示する
                pictureBox1.Image = temp.GetBitmap();
                //ImageFrameを破棄する
                temp.Dispose();
            }
        }
    }
}
